@@ -1,14 +1,19 @@
 import time
 import urllib
-from oauth_provider.tests.auth import BaseOAuthTestCase
-import oauth2 as oauth
 import json
-from django.test.client import RequestFactory
-from oauth_provider.models import Token, Resource
-from oauth_provider import utils
-from oauth_provider.store import store as oauth_provider_store
+import datetime
 from urlparse import parse_qs, urlparse
 
+from django.conf import settings
+from django.test.client import RequestFactory
+
+import oauth2 as oauth
+
+from oauth_provider.tests.auth import BaseOAuthTestCase, METHOD_AUTHORIZATION_HEADER
+from oauth_provider.models import Token, Scope
+from oauth_provider import utils, responses
+from oauth_provider.store import store as oauth_provider_store
+
 
 class OAuthTestsBug10(BaseOAuthTestCase):
     """
@@ -68,7 +73,7 @@ class OauthTestIssue24(BaseOAuthTestCase):
             consumer=self.consumer,
             user=self.jane,
             token_type=2,
-            resource=self.resource
+            scope=self.scope
         )
         self.access_token.save()
 
@@ -240,6 +245,157 @@ class OAuthTestsBug2UrlParseNonHttpScheme(BaseOAuthTestCase):
         # assert query part of url is not malformed
         assert "?q=1&" in response["Location"]
 
+class OAuthTestIssue41XForwardedProto(BaseOAuthTestCase):
+
+    def setUp(self):
+        super(OAuthTestIssue41XForwardedProto, self).setUp()
+        self._request_token(METHOD_AUTHORIZATION_HEADER)
+        self._authorize_and_access_token_using_form(METHOD_AUTHORIZATION_HEADER)
+        print
+
+    def _make_GET_auth_header(self, url):
+        token = oauth.Token(self.ACCESS_TOKEN_KEY, self.ACCESS_TOKEN_SECRET)
+        consumer = oauth.Consumer(self.CONSUMER_KEY, self.CONSUMER_SECRET)
+
+        request = oauth.Request.from_consumer_and_token(
+            consumer=consumer,
+            token=token,
+            http_method="GET",
+            http_url=url,
+        )
+
+        # Sign the request.
+        signature_method = oauth.SignatureMethod_HMAC_SHA1()
+        request.sign_request(signature_method, consumer, token)
+        return request.to_header()["Authorization"]
+
+    def test_when_same_protocol(self):
+        """Test that signature vierifies when protocol used for signing is same as used in request
+        """
+        url = "http://testserver/oauth/none/"
+        kwargs = {
+            "HTTP_AUTHORIZATION": self._make_GET_auth_header(url),
+        }
+        response = self.c.get(url.replace('http', 'https'), **kwargs)
+        self.assertEqual(response.status_code, 200)
+
+        url = "https://testserver:80/oauth/none/"
+        kwargs = {
+            # this tells django test client to pretend it was https request
+            'wsgi.url_scheme': "https",
+            "HTTP_AUTHORIZATION": self._make_GET_auth_header(url),
+        }
+        response = self.c.get(url, **kwargs)
+        self.assertEqual(response.status_code, 200)
+
+
+    def test_when_protocol_mismatch(self):
+        """Test that signature does not vierifies when protocol is diffrent from that which was used for signing request
+        """
+        url = "https://testserver:80/oauth/none/"
+        kwargs = {
+            'wsgi.url_scheme': "http",
+            "HTTP_AUTHORIZATION": self._make_GET_auth_header(url),
+        }
+        response = self.c.get(url.replace('https', 'http'), **kwargs)
+        assert response == responses.COULD_NOT_VERIFY_OAUTH_REQUEST_RESPONSE
+        self.assertEqual(response.status_code, 401)
+
+        url = "http://testserver:80/oauth/none/"
+        kwargs = {
+            # this tells django test client to pretend it was https request
+            'wsgi.url_scheme': "https",
+            "HTTP_AUTHORIZATION": self._make_GET_auth_header(url),
+        }
+        response = self.c.get(url.replace('http', 'https'), **kwargs)
+        assert response == responses.COULD_NOT_VERIFY_OAUTH_REQUEST_RESPONSE
+        self.assertEqual(response.status_code, 401)
+
+    def test_when_x_forwarded_proto_header_has_valid_protocol(self):
+        """Test that signature verifies when X-Forwarded-Proto HTTP header has same protocol as one that was used for signing request
+        """
+        url = "https://testserver/oauth/none/"
+        kwargs = {
+            'wsgi.url_scheme': "http",
+            'HTTP_AUTHORIZATION': self._make_GET_auth_header(url),
+            'HTTP_X_FORWARDED_PROTO': 'https',
+        }
+        response = self.c.get(url.replace('https', 'http'), **kwargs)
+        self.assertEqual(response.status_code, 200)
+
+
+        url = "http://testserver/oauth/none/"
+        kwargs = {
+            'wsgi.url_scheme': "https",
+            "HTTP_AUTHORIZATION": self._make_GET_auth_header(url),
+            "HTTP_X_FORWARDED_PROTO": "http",
+        }
+
+        response = self.c.get(url.replace('http', 'https'), **kwargs)
+        self.assertEqual(response.status_code, 200)
+
+
+class OAuthTestIssue16NoncesCheckedAgainstTimestamp(BaseOAuthTestCase):
+    def test_timestamp_ok(self):
+        self._request_token()
+        self._authorize_and_access_token_using_form()
+
+        parameters = {
+            'oauth_consumer_key': self.CONSUMER_KEY,
+            'oauth_signature_method': "PLAINTEXT",
+            'oauth_version': "1.0",
+            'oauth_token': self.ACCESS_TOKEN_KEY,
+            'oauth_timestamp': str(int(time.time())),
+            'oauth_nonce': str(int(time.time()))+"nonce1",
+            'oauth_signature': "%s&%s" % (self.CONSUMER_SECRET, self.ACCESS_TOKEN_SECRET),
+            }
+
+        response = self.c.get("/oauth/photo/", parameters)
+
+        self.assertEqual(response.status_code, 200)
+
+    def test_timestamp_repeated_nonce(self):
+        self._request_token()
+        self._authorize_and_access_token_using_form()
+
+        timestamp = str(int(time.time()))
+        nonce = timestamp + "nonce"
+        parameters = {
+            'oauth_consumer_key': self.CONSUMER_KEY,
+            'oauth_signature_method': "PLAINTEXT",
+            'oauth_version': "1.0",
+            'oauth_token': self.ACCESS_TOKEN_KEY,
+            'oauth_timestamp': timestamp,
+            'oauth_nonce': nonce,
+            'oauth_signature': "%s&%s" % (self.CONSUMER_SECRET, self.ACCESS_TOKEN_SECRET),
+            }
+
+        response = self.c.get("/oauth/photo/", parameters)
+        self.assertEqual(response.status_code, 200)
+
+        response = self.c.get("/oauth/photo/", parameters)
+        self.assertEqual(response.status_code, 401)
+
+    def test_timestamp_old_nonce(self):
+        self._request_token()
+        self._authorize_and_access_token_using_form()
+
+        #make this nonce older
+        timestamp = str(int(datetime.datetime.now().strftime("%s")) - (settings.OAUTH_NONCE_VALID_PERIOD + 1))
+        nonce = timestamp + "nonce"
+        parameters = {
+            'oauth_consumer_key': self.CONSUMER_KEY,
+            'oauth_signature_method': "PLAINTEXT",
+            'oauth_version': "1.0",
+            'oauth_token': self.ACCESS_TOKEN_KEY,
+            'oauth_timestamp': timestamp,
+            'oauth_nonce': nonce,
+            'oauth_signature': "%s&%s" % (self.CONSUMER_SECRET, self.ACCESS_TOKEN_SECRET),
+            }
+
+        response = self.c.get("/oauth/photo/", parameters)
+        self.assertEqual(response.status_code, 401)
+
 
 class OAuthTestIssue39(BaseOAuthTestCase):
     """
@@ -247,10 +403,11 @@ class OAuthTestIssue39(BaseOAuthTestCase):
     """
     def setUp(self):
         super(OAuthTestIssue39, self).setUp()
-        Resource.objects.create(name='resource2')
+        Scope.objects.create(name='scope1')
+        Scope.objects.create(name='scope2')
 
     def test_different_token_scopes(self):
-        self._request_token(scope='all')
+        self._request_token(scope='scope1')
         # Authorization code below copied from BaseOAuthTestCase
         self.c.login(username=self.username, password=self.password)
         parameters = self.authorization_parameters = {'oauth_token': self.request_token.key}
@@ -269,7 +426,8 @@ class OAuthTestIssue39(BaseOAuthTestCase):
         self.c.logout()
         # Changed line - change the scope of access token
         # access token's scope should be same as request token
-        self._access_token(oauth_verifier=oauth_verifier, oauth_token=self.request_token.key, scope='resource2')
+        self._access_token(oauth_verifier=oauth_verifier, oauth_token=self.request_token.key, scope='scope2')
 
         access_token = Token.objects.get(key=self.ACCESS_TOKEN_KEY)
-        self.assertEqual(access_token.resource.name, 'all')
+        self.assertEqual(access_token.scope.name, 'scope1')
+
